"use strict";

var autoprefixer = require('gulp-autoprefixer');
var browserSync = require("browser-sync").create();
var cleanCss = require("gulp-clean-css");
var concat = require("gulp-concat");
var del = require('del');
var gulp = require("gulp");
var header = require("gulp-header");
var jshint = require("gulp-jshint");
var less = require("gulp-less");
var pkg = require("./package.json");
var plumber = require("gulp-plumber");
var rename = require("gulp-rename");
var uglify = require("gulp-uglify");

var year = new Date().getFullYear();
var headerText = [
    "/**",
    " * <%= pkg.name %> v<%= pkg.version %>",
    " * <%= pkg.homepage %>",
    " * Copyright <%= year %> <%= pkg.author %>",
    " * Released under the <%= pkg.license %> license",
    " */",
    ""
].join("\n");

var handlePlumberError = function(error) {
    console.log(error.message);
    this.emit('end');
};

gulp.task("browser-sync:init", function() {
    browserSync.init({
        server: {
            baseDir: "./"
        }
    });
});

gulp.task("browser-sync:reload", function() {
    browserSync.reload();
});

gulp.task("build:css", function() {
    return gulp.src("src/less/**/*.less")
        .pipe(plumber({ errorHandler: handlePlumberError }))
        .pipe(concat("bootstrap-imgupload.css"))
        .pipe(less())
        .pipe(autoprefixer("last 3 versions"))
        .pipe(header(headerText, { pkg: pkg, year: year }))
        .pipe(gulp.dest("dist/css"))
        .pipe(rename({ suffix: ".min" }))
        .pipe(cleanCss())
        .pipe(header(headerText, { pkg: pkg, year: year }))
        .pipe(gulp.dest("dist/css"));
});

gulp.task("build:js", function() {
    return gulp.src("src/js/**/*.js")
        .pipe(plumber({ errorHandler: handlePlumberError }))
        .pipe(jshint())
        .pipe(jshint.reporter("default"))
        .pipe(jshint.reporter("fail"))
        .pipe(concat("bootstrap-imgupload.js"))
        .pipe(header(headerText, { pkg: pkg, year: year }))
        .pipe(gulp.dest("dist/js"))
        .pipe(rename({ suffix: ".min" }))
        .pipe(uglify())
        .pipe(header(headerText, { pkg: pkg, year: year }))
        .pipe(gulp.dest("dist/js"));
});

gulp.task("build", ["build:css", "build:js"]);

gulp.task("clean:css", function() {
    return del(["dist/css/**/*.css"]);
});

gulp.task("clean:js", function() {
    return del(["dist/js/**/*.js"]);
});

gulp.task("clean", ["clean:css", "clean:js"]);

gulp.task("watch", ["browser-sync:init"], function() {
    gulp.watch("index.html", ["browser-sync:reload"]);
    gulp.watch("src/less/**/*.less", ["build:css", "browser-sync:reload"]);
    gulp.watch("src/js/**/*.js", ["build:js", "browser-sync:reload"]);
});

gulp.task("default", ["build", "watch"]);
